# This script will measure the size of each vault store partition and export the result into a CSV file.
$CsvFile = "$HOME\Desktop\Partition_Size_Report$(get-date -f yyyy-MM-dd-hh-mm).csv" #This variable is for where the csv file goes. The default is the desktop of the account used to run the script. Change this to whatever you like.
$SqlServer = "SERVERNAME" #Change SERVERNAME to the hostname of your EV SQL server.
Add-PSSnapin SqlServerCmdletSnapin100
Add-PSSnapin SqlServerProviderSnapin100 #This script requires SQL Server 2008 R2 or greater on the server as well as SQL Server 2008 R2 Management Objects & Windows PowerShell Extensions for SQL Server on the machine running the script. There is a handy guide to this here: http://jasonq.com/2012/03/3-things-to-do-if-invoke-sqlcmd-is-not-recognized-in-windows-powershell/
$Partitions = Invoke-Sqlcmd -Query "use EnterpriseVaultDirectory SELECT DISTINCT view_VaultStore_StorageServer.ComputerNameAlternate as 'EV Server', PartitionEntry.PartitionName as 'Partition Name', PartitionEntry.PartitionRootPath as 'Path', PartitionEntry.RemotePartitionRootPath as 'Remote Path' from view_VaultStore_StorageServer INNER JOIN PartitionEntry ON view_VaultStore_StorageServer.VaultStoreEntryId=Partitionentry.VaultStoreEntryId ORDER BY [EV Server] asc, [Partition Name] asc, Path asc" -ServerInstance $SqlServer
$Partitions | Add-Member -MemberType NoteProperty -Name 'Partition Size' -Value notset
$Partitions | ForEach-Object {$_.'Partition Size' = (Get-ChildItem $_.'Remote Path'-recurse | Measure-Object -property length -sum).sum/1MB}
$Partitions | Export-Csv $CsvFile_ -Force
(Get-Content $CsvFile | Select-Object -Skip 1) | Set-Content $CsvFile